from monicahq import Session
import requests, json

class Client():
    def __init__(self, session):
        """Initialize based upon a session"""
        if type(session) != Session.Session:
            raise TypeError(f"session variable is not of type monicahq.Session.Session, but {type(session)}")

        self.session = session

    def search_contacts(self, count=100):
        """Get list of contacts as JSON"""

        url = f"{self.session.url}/contacts?limit={count}"
        r = requests.get(url, headers=self.session.headers)
        return json.loads(r.text)


"""Set up a session with the monicahq server"""

import requests, json

class Session():
    def __init__(self, host, token):
        """Initialize using hostname and token"""
        self.token = f'Bearer {token}'
        self.headers = {'Authorization': self.token}
        self.host = host
        self.url = f"https://{self.host}/api"

    def create(self):
        """Create the session"""
        r=requests.get(self.url,headers=self.headers)
        data = json.loads(r.text)
        try:
            data['success']
            return True
        except:
            return False
        


from setuptools import setup, find_packages


setup(
    name='monicahq-client',
    version='0.1.1',
    license='MIT',
    author="Darko Sajben",
    author_email='sajbendarko94@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/sajben94/monicahq-client',
    keywords='monicahq',
    install_requires=[
          'requests',
      ],
)
